#' ggthemes
#'
#' This package contains extra themes, scales, and geoms, and
#' functions for and related to \pkg{ggplot2}. See
#' \url{https://jrnold.github.io/ggthemes/} for documentation.
#'
#' @name ggthemes
#' @docType package
#' @importFrom ggplot2 ggplot theme ggproto aes draw_key_path
#' @importFrom grid grobTree grobName gTree gList segmentsGrob gpar
#' @importFrom scales manual_pal div_gradient_pal seq_gradient_pal
#' @importFrom graphics abline axis text points
#' @importFrom methods hasArg as
#' @importFrom graphics par
"_PACKAGE"

globalVariables(".data")
